Unit MPEG3Player;
{
an interface to WinAmp 1.x or greater player to play mp3 audio files
Uses WAInt unit by Brendin Emslie to send messages to WinAmp
Author:  Giuseppe Lo Presti
Date;    Sep 1998
Version: 1.1

History:
1.0 (May  7, 1998) - First release
1.1 (Sep  3, 1998) - CloseWinAmp procedure added
1.2 (May 16, 1999) - Some issues corrected, WinAmp 2.x compatible
}

Interface

Uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, MP3About, DsgnIntf;

Type
  TMP3Status = (mp3Playing, mp3Pause, mp3Stop, mp3Unknown);
  TMP3Player = class(TComponent)
  private
	 { Private declarations }
	 fAbout : string;
	 fName : string;
	 fWinAmpPath : string;
	 procedure SetFileName(value : string);
	 procedure SetPosition(value : integer);
	 function GetPosition : integer;
	 function GetLength : integer;
	 function GetStatus : TMP3Status;
  protected
	 { Protected declarations }
  public
	 { Public declarations }
	 constructor Create(AOwner : TComponent); override;
	 procedure StartWinAmp;
	 procedure CloseWinAmp;
	 procedure Play;
	 procedure Pause;
	 procedure Stop;
  published
	 { Published declarations }
	 property About : string read fAbout write fAbout;
	 property FileName : string read fName write SetFileName;
	 property Position : integer read GetPosition write SetPosition;
	 property Length : integer read GetLength;
	 property Status : TMP3Status read GetStatus;
	 property WinAmpPath : string read fWinAmpPath write fWinAmpPath;
  end;


  TAboutProperty = class(TStringProperty)
  public
	 procedure Edit; override;
	 function GetAttributes: TPropertyAttributes; override;
  end;

  TWAPProperty = class(TStringProperty)        // WinAmp Path
  public
	 procedure Edit; override;
	 function GetAttributes: TPropertyAttributes; override;
  end;

Procedure Register;


Implementation

uses WAInt, Dialogs;


{ TMP3Player }

Constructor TMP3Player.Create(AOwner : TComponent);
begin
	Inherited Create(AOwner);
	fAbout:= 'Click here   -->';
end;

procedure TMP3Player.StartWinAmp;
var
	com : string; pcom : pchar;
begin
	com:= fWinAmpPath + #0;        // makes string null-terminated
	pcom:= @com[1];
	WinExec(pcom, SW_HIDE);
end;

procedure TMP3Player.CloseWinAmp;
begin
	WAInt.Terminate;
end;

procedure TMP3Player.SetFileName(value : string);
{ in this version I don't support multiple mp3 files, although WinAmp does }
begin
	if fName <> value Then
		begin
		fName:= value;
		DeletePlayList;
		// I suppose WinAmp is already started
		If fName <> '' Then AddMP3ToPlayList(fName);
		// wait until loaded
		While GetStatus <> mp3Stop Do;
		end;
end;

function TMP3Player.GetLength : integer;
begin
	result:= GetOutputTime(1) * 1000;    // in milliseconds
end;

function TMP3Player.GetPosition : integer;
begin
	result:= GetOutputTime(0);           // in milliseconds
end;

procedure TMP3Player.SetPosition(value : integer);
begin
	JumpToTime(value);
end;

function TMP3Player.GetStatus : TMP3Status;
begin
	Case PlayBackStatus of
		1 : result:= mp3Playing;
		3 : result:= mp3Pause;
		0 : result:= mp3Stop;
	Else result:= mp3Unknown;
	end;
end;

procedure TMP3Player.Play;
begin
	Button2;
end;

procedure TMP3Player.Pause;
begin
	Button3;
end;

procedure TMP3Player.Stop;
begin
	Button4;
end;


{ TAboutProperty }

Procedure TAboutProperty.Edit;
var
	AboutDlg : TMP3AboutBox;
begin
	AboutDlg:= TMP3AboutBox.Create(Application);
	With AboutDlg Do
		begin
		(* component bitmap preloaded into .dfm file *)
		ComponentName.caption:= 'TMP3Player';
		Version.caption:= Version.caption + '1.2';
		Release.caption:= Release.caption + 'May 16, 1999.';
		end;
	Try
		AboutDlg.ShowModal;
	Finally
		AboutDlg.Free;
	end;
end;

Function TAboutProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog, paReadOnly];
end;


{ TWAPProperty }

procedure TWAPProperty.Edit;
var
  WAFileOpen: TOpenDialog;
begin
  WAFileOpen:= TOpenDialog.Create(Application);
  WAFileOpen.fileName:= GetValue;
  WAFileOpen.filter:= 'WinAmp player|winamp.exe';
  WAFileOpen.helpContext:= 0;
  WAFileOpen.options:= WAFileOpen.Options + [ofPathMustExist, ofFileMustExist];
  Try
	 If WAFileOpen.Execute Then SetValue(WAFileOpen.fileName);
  Finally
	 WAFileOpen.Free;
  end;
end;

function TWAPProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog, paRevertable];
end;


Procedure Register;
begin
  RegisterComponents('System', [TMP3Player]);
  RegisterPropertyEditor(TypeInfo(string), TMP3Player, 'About', TAboutProperty);
  RegisterPropertyEditor(TypeInfo(string), TMP3Player, 'WinAmpPath', TWAPProperty);
end;


end.

